{
	"namespace": "elasticc.v0_9",
	"name": "diaForcedSource",
	"type": "record",
	"fields": [
		{"name": "diaForcedSourceId", "type": "long"},
		{"name": "ccdVisitId",  "type": "long"},
		{"name": "diaObjectId", "type": "long"},
		{"name": "midPointTai", "type": "double"},
		{"name": "filterName", "type": "string"},
		{"name": "psFlux", "type": "float"},
		{"name": "psFluxErr", "type": "float"},
		{"name": "totFlux", "type": "float"},
		{"name": "totFluxErr", "type":"float"}
	]
}
