{
	"namespace": "elasticc.v0_9",
	"name": "diaObject",
	"type": "record",
	"fields": [
		{"name": "diaObjectId", "type": "long"},
		{"name": "simVersion",  "type": ["null", "string"], "doc": "diaObject provenance"},
		{"name": "ra", "type": "double"},
		{"name": "decl", "type": "double"},
		{"name": "mwebv", "type": ["null", "float"], "default": null},
        {"name": "mwebv_err", "type": ["null", "float"], "default": null},
        {"name": "z_final", "type": ["null", "float"], "default": null},
        {"name": "z_final_err", "type": ["null", "float"], "default": null},
        {"name": "hostgal_ellipticity", "type": ["null", "float"], "default": null},
        {"name": "hostgal_sqradius", "type": ["null", "float"], "default": null},
        {"name": "hostgal_zspec", "type": ["null", "float"], "default": null},
        {"name": "hostgal_zspec_err", "type": ["null", "float"], "default": null},
        {"name": "hostgal_zphot", "type": ["null", "float"], "default": null},
        {"name": "hostgal_zphot_err", "type": ["null", "float"], "default": null},
        {"name": "hostgal_zphot_q000", "type": ["null", "float"], "default": null},
        {"name": "hostgal_zphot_q010", "type": ["null", "float"], "default": null},
        {"name": "hostgal_zphot_q020", "type": ["null", "float"], "default": null},
        {"name": "hostgal_zphot_q030", "type": ["null", "float"], "default": null},
        {"name": "hostgal_zphot_q040", "type": ["null", "float"], "default": null},
        {"name": "hostgal_zphot_q050", "type": ["null", "float"], "default": null},
        {"name": "hostgal_zphot_q060", "type": ["null", "float"], "default": null},
        {"name": "hostgal_zphot_q070", "type": ["null", "float"], "default": null},
        {"name": "hostgal_zphot_q080", "type": ["null", "float"], "default": null},
        {"name": "hostgal_zphot_q090", "type": ["null", "float"], "default": null},
        {"name": "hostgal_zphot_q100", "type": ["null", "float"], "default": null},
        {"name": "hostgal_zphot_p50", "type": ["null", "float"], "default": null},
        {"name": "hostgal_mag_u", "type": ["null", "float"], "default": null},
        {"name": "hostgal_mag_g", "type": ["null", "float"], "default": null},
        {"name": "hostgal_mag_r", "type": ["null", "float"], "default": null},
        {"name": "hostgal_mag_i", "type": ["null", "float"], "default": null},
        {"name": "hostgal_mag_z", "type": ["null", "float"], "default": null},
        {"name": "hostgal_mag_Y", "type": ["null", "float"], "default": null},
        {"name": "hostgal_ra", "type": ["null", "float"], "default": null},
        {"name": "hostgal_dec", "type": ["null", "float"], "default": null},
        {"name": "hostgal_snsep", "type": ["null", "float"], "default": null},
        {"name": "hostgal_magerr_u", "type": ["null", "float"], "default": null},
        {"name": "hostgal_magerr_g", "type": ["null", "float"], "default": null},
        {"name": "hostgal_magerr_r", "type": ["null", "float"], "default": null},
        {"name": "hostgal_magerr_i", "type": ["null", "float"], "default": null},
        {"name": "hostgal_magerr_z", "type": ["null", "float"], "default": null},
        {"name": "hostgal_magerr_Y", "type": ["null", "float"], "default": null},
        {"name": "hostgal2_ellipticity", "type": ["null", "float"], "default": null},
        {"name": "hostgal2_sqradius", "type": ["null", "float"], "default": null},
        {"name": "hostgal2_zspec", "type": ["null", "float"], "default": null},
        {"name": "hostgal2_zspec_err", "type": ["null", "float"], "default": null},
        {"name": "hostgal2_zphot", "type": ["null", "float"], "default": null},
        {"name": "hostgal2_zphot_err", "type": ["null", "float"], "default": null},
        {"name": "hostgal2_zphot_q000", "type": ["null", "float"], "default": null},
        {"name": "hostgal2_zphot_q010", "type": ["null", "float"], "default": null},
        {"name": "hostgal2_zphot_q020", "type": ["null", "float"], "default": null},
        {"name": "hostgal2_zphot_q030", "type": ["null", "float"], "default": null},
        {"name": "hostgal2_zphot_q040", "type": ["null", "float"], "default": null},
        {"name": "hostgal2_zphot_q050", "type": ["null", "float"], "default": null},
        {"name": "hostgal2_zphot_q060", "type": ["null", "float"], "default": null},
        {"name": "hostgal2_zphot_q070", "type": ["null", "float"], "default": null},
        {"name": "hostgal2_zphot_q080", "type": ["null", "float"], "default": null},
        {"name": "hostgal2_zphot_q090", "type": ["null", "float"], "default": null},
        {"name": "hostgal2_zphot_q100", "type": ["null", "float"], "default": null},
        {"name": "hostgal2_zphot_p50", "type": ["null", "float"], "default": null},
        {"name": "hostgal2_mag_u", "type": ["null", "float"], "default": null},
        {"name": "hostgal2_mag_g", "type": ["null", "float"], "default": null},
        {"name": "hostgal2_mag_r", "type": ["null", "float"], "default": null},
        {"name": "hostgal2_mag_i", "type": ["null", "float"], "default": null},
        {"name": "hostgal2_mag_z", "type": ["null", "float"], "default": null},
        {"name": "hostgal2_mag_Y", "type": ["null", "float"], "default": null},
        {"name": "hostgal2_ra", "type": ["null", "float"], "default": null},
        {"name": "hostgal2_dec", "type": ["null", "float"], "default": null},
        {"name": "hostgal2_snsep", "type": ["null", "float"], "default": null},
        {"name": "hostgal2_magerr_u", "type": ["null", "float"], "default": null},
        {"name": "hostgal2_magerr_g", "type": ["null", "float"], "default": null},
        {"name": "hostgal2_magerr_r", "type": ["null", "float"], "default": null},
        {"name": "hostgal2_magerr_i", "type": ["null", "float"], "default": null},
        {"name": "hostgal2_magerr_z", "type": ["null", "float"], "default": null},
        {"name": "hostgal2_magerr_Y", "type": ["null", "float"], "default": null}
	]
}
